Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(256)

Unified Diff: src/compiler/interpreter-assembler.h

Issue 1333843002: [runtime] Move binary operator fallbacks into the runtime. (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: No need for frame states in bytecode handlers. Add test case. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: src/compiler/interpreter-assembler.h
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h
index d6a75db89f840dfc7b367c0ae8dddd9e0f47461e..0949fbb5e6c5a9f824934741b2f590865373626b 100644
--- a/src/compiler/interpreter-assembler.h
+++ b/src/compiler/interpreter-assembler.h
@@ -12,6 +12,7 @@
#include "src/builtins.h"
#include "src/frames.h"
#include "src/interpreter/bytecodes.h"
+#include "src/runtime/runtime.h"
namespace v8 {
namespace internal {
@@ -86,9 +87,8 @@ class InterpreterAssembler {
Node* CallIC(CallInterfaceDescriptor descriptor, Node* target, Node* arg1,
Node* arg2, Node* arg3, Node* arg4, Node* arg5);
- // Call JS builtin.
- Node* CallJSBuiltin(int context_index, Node* receiver);
- Node* CallJSBuiltin(int context_index, Node* receiver, Node* arg1);
+ // Call runtime function.
+ Node* CallRuntime(Runtime::FunctionId function_id, Node* arg1, Node* arg2);
// Returns from the function.
void Return();
« no previous file with comments | « src/api.cc ('k') | src/compiler/interpreter-assembler.cc » ('j') | src/compiler/linkage.h » ('J')

Powered by Google App Engine
This is Rietveld 408576698